import React, { useState, useEffect } from 'react';
import { Card, CardContent } from '@/components/ui/card';
import { Input } from '@/components/ui/input';
import { Button } from '@/components/ui/button';
import { Alert, AlertDescription } from '@/components/ui/alert';
import { Loader } from 'lucide-react';

const FlickrMemories = () => {
  const [username, setUsername] = useState('');
  const [photos, setPhotos] = useState([]);
  const [loading, setLoading] = useState(false);
  const [error, setError] = useState('');
  
  // Get today's date
  const today = new Date();
  const month = today.getMonth() + 1;
  const day = today.getDate();
  
  const fetchPhotos = async () => {
    if (!username) {
      setError('Please enter a Flickr username');
      return;
    }
    
    setLoading(true);
    setError('');
    
    try {
      // Note: In a real application, you would need to replace API_KEY with your actual Flickr API key
      const API_KEY = '8fc4ec167bb1d1043ef4a4c942ccf3a9';
      
      // First, get the user's NSID using their username
      const userResponse = await fetch(
        `https://api.flickr.com/services/rest/?method=flickr.people.findByUsername&api_key=${API_KEY}&username=${username}&format=json&nojsoncallback=1`
      );
      const userData = await userResponse.json();
      
      if (userData.stat !== 'ok') {
        throw new Error('User not found');
      }
      
      const userId = userData.user.nsid;
      
      // Then, search for photos by this user on this day
      const photosResponse = await fetch(
        `https://api.flickr.com/services/rest/?method=flickr.photos.search&api_key=${API_KEY}&user_id=${userId}&min_taken_date=${month}-${day}&max_taken_date=${month}-${day}&format=json&nojsoncallback=1&extras=url_m,date_taken`
      );
      const photosData = await photosResponse.json();
      
      if (photosData.stat !== 'ok') {
        throw new Error('Failed to fetch photos');
      }
      
      setPhotos(photosData.photos.photo);
      
    } catch (err) {
      setError(err.message || 'Failed to fetch photos');
    } finally {
      setLoading(false);
    }
  };
  
  return (
    <div className="max-w-4xl mx-auto p-4">
      <div className="mb-8">
        <h1 className="text-3xl font-bold mb-4">Flickr Memories</h1>
        <p className="text-gray-600 mb-4">
          View photos taken on {month}/{day} from previous years
        </p>
        
        <div className="flex gap-4 mb-4">
          <Input
            type="text"
            placeholder="Enter Flickr username"
            value={username}
            onChange={(e) => setUsername(e.target.value)}
            className="flex-grow"
          />
          <Button 
            onClick={fetchPhotos}
            disabled={loading}
          >
            {loading ? <Loader className="animate-spin mr-2" /> : 'Search'}
          </Button>
        </div>
        
        {error && (
          <Alert variant="destructive" className="mb-4">
            <AlertDescription>{error}</AlertDescription>
          </Alert>
        )}
      </div>
      
      <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-4">
        {photos.map((photo) => (
          <Card key={photo.id} className="overflow-hidden">
            <CardContent className="p-0">
              <img
                src={photo.url_m}
                alt={photo.title}
                className="w-full h-64 object-cover"
              />
              <div className="p-4">
                <h3 className="font-medium mb-2">{photo.title || 'Untitled'}</h3>
                <p className="text-sm text-gray-600">
                  Taken on: {new Date(photo.datetaken).toLocaleDateString()}
                </p>
              </div>
            </CardContent>
          </Card>
        ))}
      </div>
      
      {photos.length === 0 && !loading && !error && (
        <p className="text-center text-gray-600">
          No photos found for this date
        </p>
      )}
    </div>
  );
};

export default FlickrMemories;